virt-manager/virtinst-add-ppc64-arch-support.patch
Charles Arnold 9851188d58 - bsc#962221 - virt-install: 'NoneType' object has no attribute
'isdigit' 
  eae7dc06-fix-URL-installs-when-content-length-header-missing.patch

OBS-URL: https://build.opensuse.org/package/show/Virtualization/virt-manager?expand=0&rev=291
2016-01-18 20:48:51 +00:00

33 lines
1.2 KiB
Diff

Reference: bnc#869024
Add s390x and ppc64 support
Index: virt-manager-1.3.2/virtinst/urlfetcher.py
===================================================================
--- virt-manager-1.3.2.orig/virtinst/urlfetcher.py
+++ virt-manager-1.3.2/virtinst/urlfetcher.py
@@ -430,6 +430,10 @@ def _distroFromSUSEContent(fetcher, arch
arch = "i586"
elif cbuf.find("s390x") != -1:
arch = "s390x"
+ elif cbuf.find("ppc64") != -1:
+ arch = "ppc64"
+ elif cbuf.find("ppc64le") != -1:
+ arch = "ppc64le"
dclass = GenericDistro
if distribution:
@@ -969,10 +973,12 @@ class SuseDistro(Distro):
oldkern += "64"
oldinit += "64"
- if self.arch == "s390x":
+ if self.arch == "s390x" or \
+ self.arch == "ppc64" or self.arch == "ppc64le":
+
self._hvm_kernel_paths = [("boot/%s/linux" % self.arch,
"boot/%s/initrd" % self.arch)]
# No Xen on s390x
self._xen_kernel_paths = []
else:
# Tested with Opensuse >= 10.2, 11, and sles 10
@@ -969,10 +973,12 @@ class SuseDistro(Distro):
self._hvm_kernel_paths = [("boot/%s/linux" % self.arch,
"boot/%s/initrd" % self.arch)]
- # No Xen on s390x
+ # No Xen on s390x or ppc64
self._xen_kernel_paths = []
else: